@@ -24,7 +24,8 @@
 #include <config.h>
 #endif
 
-#include <gnome.h>
+#include <glib.h>
+#include <glib/gi18n.h>
 #include <glade/glade.h>
 #include "gok-log.h"
 #include "gok-keyboard.h"
