@@ -24,7 +24,6 @@
 #endif
 
 #include <string.h>
-#include <libgnome/gnome-program.h>
 #include <glib.h>
 #include <glib/gi18n.h>
 #include "gok-key.h"
@@ -1525,18 +1524,12 @@ gok_key_status_image (GokKey *key)
 #else
 	icon_name = "small-empty.png";
 #endif
-	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
-					  icon_name,
-					  FALSE, NULL);
-
-	if (file) {
-		image = gtk_image_new_from_file (file);
-		g_free (file);
-	}
+	file = g_strdup_printf (DATADIR "/gok/%s", icon_name);
+	image = gtk_image_new_from_file (file);
+	g_free (file);
 
 	return image;
 }
-	
 
 /**
 * gok_key_create_image_widget
@@ -2433,9 +2426,11 @@ gok_key_get_image_filename (GokKey* pKey)
 	gchar *filename = NULL;
 	g_assert (pKey != NULL);
 
-	filename = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
-					      pKey->pImage->Filename,
-					      FALSE, NULL);
+	if (pKey->pImage && pKey->pImage->Filename)
+	{
+		filename = g_strdup_printf (DATADIR "/gok/%s",
+					    pKey->pImage->Filename);
+	}
 	return filename;
 }
 
