@@ -19,7 +19,6 @@
 * Boston, MA 02111-1307, USA.
 */
 
-#include <gnome.h>
 #include <glade/glade.h>
 #include "gok-feedback.h"
 
@@ -43,4 +42,5 @@ void gok_feedbacks_update_sound_combo (void);
 gboolean gok_page_feedbacks_get_changed (void);
 void gok_page_feedbacks_set_changed (gboolean bTrueFalse);
 void gok_page_feedbacks_feedback_changed (GtkEditable* pEditControl);
+void gok_page_feedbacks_check_speech_toggled (GtkToggleButton *button);
 
