@@ -26,6 +26,8 @@
 #include <dirent.h>
 #include <locale.h>
 #include <gconf/gconf-client.h>
+#include <glib.h>
+#include <glib/gi18n.h>
 #include "gok-scanner.h"
 #include "gok-data.h"
 #include "gok-log.h"
