@@ -22,8 +22,7 @@
 #ifndef __GOKSETTINGSDIALOG_H__
 #define __GOKSETTINGSDIALOG_H__
 
-#include <gnome.h>
-#include "interface.h"
+#include <glade/glade.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -37,7 +36,6 @@ extern "C" {
 #define PAGE_NUM_PREDICTION 4
 
 gboolean gok_settingsdialog_open (gboolean bShow);
-void gok_settingsdialog_lock (void);
 void gok_settingsdialog_close (void);
 gboolean gok_settingsdialog_show (void);
 void gok_settingsdialog_hide (void);
@@ -49,6 +47,7 @@ void on_button_help (GtkButton* button, gpointer user_data);
 void gok_settingsdialog_refresh (void);
 void gok_settingsdialog_backup_settings (void);
 GtkWidget* gok_settingsdialog_get_window (void);
+GladeXML* gok_settingsdialog_get_xml (void);
 gint gok_settingsdialog_sort (gconstpointer pItem1, gconstpointer pItem2);
 
 #ifdef __cplusplus
